@@ -17,12 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
+#include <QMenu>
 #include <QTextCodec>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
-#include <qtreewidget.h>
 #include <kstandardguiitem.h>
 #include <kpushbutton.h>
 #include <interfaces/torrentfileinterface.h>
@@ -35,6 +35,7 @@
 #include <interfaces/functions.h>
 #include <groups/group.h>
 #include <groups/groupmanager.h>
+#include <torrent/queuemanager.h>
 #include <torrent/torrentfiletreemodel.h>
 #include <torrent/torrentfilelistmodel.h>
 #include "fileselectdlg.h"
@@ -45,7 +46,13 @@ using namespace bt;
 namespace kt
 {
 
-	FileSelectDlg::FileSelectDlg(kt::GroupManager* gman,const QString & group_hint,QWidget* parent) : KDialog(parent),gman(gman),initial_group(0),show_file_tree(true)
+	FileSelectDlg::FileSelectDlg(kt::QueueManager* qman,kt::GroupManager* gman,const QString & group_hint,QWidget* parent) 
+		: KDialog(parent),
+		qman(qman),
+		gman(gman),
+		initial_group(0),
+		show_file_tree(true),
+		already_downloaded(0)
 	{
 		setupUi(mainWidget());
 		m_file_view->setAlternatingRowColors(true);
@@ -61,6 +68,11 @@ namespace kt
 		
 		m_downloadLocation->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
 		m_completedLocation->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
+		
+		m_download_location_history->setIcon(KIcon("view-history"));
+		m_download_location_history->setPopupMode(QToolButton::MenuButtonPopup);
+		m_move_when_completed_history->setIcon(KIcon("view-history"));
+		m_move_when_completed_history->setPopupMode(QToolButton::MenuButtonPopup);
 
 		
 		encodings = QTextCodec::availableMibs();
@@ -86,7 +98,7 @@ namespace kt
 		bg->setExclusive(true);
 		
 		m_filter->setClearButtonShown(true);
-		m_filter->setHintText(i18n("Filter"));
+		m_filter->setClickMessage(i18n("Filter"));
 		connect(m_filter,SIGNAL(textChanged(QString)),this,SLOT(setFilter(QString)));
 
 		if (Settings::useCompletedDir())
@@ -130,13 +142,13 @@ namespace kt
 			model->setFileNamesEditable(true);
 			
 			connect(model,SIGNAL(checkStateChanged()),this,SLOT(updateSizeLabels()));
-			connect(m_downloadLocation,SIGNAL(textChanged(QString)),this,SLOT(updateSizeLabels()));
-			connect(m_downloadLocation,SIGNAL(textChanged(QString)),this,SLOT(updateExistingFiles()));
+			connect(m_downloadLocation,SIGNAL(textChanged(QString)),this,SLOT(downloadLocationChanged(QString)));
 			filter_model->setSourceModel(model);
+			filter_model->setSortRole(Qt::UserRole);
+			m_file_view->setSortingEnabled(true);
 			m_file_view->expandAll();
 			
 			updateSizeLabels();
-			updateExistingFiles();
 			
 			if (!tc->getStats().multi_file_torrent)
 			{
@@ -154,8 +166,6 @@ namespace kt
 
 			m_file_view->setAlternatingRowColors(false);
 			m_file_view->setRootIsDecorated(show_file_tree && tc->getStats().multi_file_torrent);
-			m_file_view->resizeColumnToContents(0);
-			m_file_view->resizeColumnToContents(1);
 			return exec();
 		}
 		return QDialog::Rejected;
@@ -170,13 +180,13 @@ namespace kt
 	{
 		QStringList pe_ex;
 		
-		QString cn = m_completedLocation->url().toLocalFile();
-		if (!cn.endsWith(bt::DirSeparator()))
-			cn += bt::DirSeparator();
+		QString cn = m_completedLocation->url().toLocalFile(KUrl::AddTrailingSlash);
+		if (m_moveCompleted->isChecked() && !cn.isEmpty())
+			move_on_completion_location_history.insert(cn);
 
-		QString dn = m_downloadLocation->url().toLocalFile();
-		if (!dn.endsWith(bt::DirSeparator()))
-			dn += bt::DirSeparator();
+		QString dn = m_downloadLocation->url().toLocalFile(KUrl::AddTrailingSlash);
+		if (!dn.isEmpty())
+			download_location_history.insert(dn);
 
 		
 		QString tld = tc->getUserModifiedFileName();
@@ -282,7 +292,6 @@ namespace kt
 				pe_ex.append(file.getUserModifiedPath());
 			}
 			file.setPathOnDisk(path);
-			file.setEmitDownloadStatusChanged(true);
 		}
 
 		if (pe_ex.count() > 0)
@@ -304,12 +313,6 @@ namespace kt
 			}
 		}
 
-		for (Uint32 i = 0;i < tc->getNumFiles();i++)
-		{
-			bt::TorrentFileInterface & file = tc->getTorrentFile(i);
-			file.setEmitDownloadStatusChanged(true);
-		}
-
 		//Setup custom download location
 		QString ddir = tc->getDataDir();
 		if (!ddir.endsWith(bt::DirSeparator()))
@@ -319,14 +322,32 @@ namespace kt
 			tc->changeOutputDir(dn + tld,bt::TorrentInterface::FULL_PATH);
 		else if (dn != ddir)
 			tc->changeOutputDir(dn, 0);
-
-		if(m_moveCompleted->checkState() == Qt::Checked)
-			tc->setMoveWhenCompletedDir(KUrl(cn));
+		
+		QStringList conflicting;
+		if (qman->checkFileConflicts(tc,conflicting))
+		{
+			QString err = i18n("Opening the torrent <b>%1</b>, "
+							   "would share one or more files with the following torrents. "
+							   "Torrents are not allowed to write to the same files. "
+							   "Please select a different location.", tc->getDisplayName());
+			KMessageBox::errorList(this,err,conflicting);
+			return;
+		}
+		
+		for (Uint32 i = 0;i < tc->getNumFiles();i++)
+		{
+			bt::TorrentFileInterface & file = tc->getTorrentFile(i);
+			file.setEmitDownloadStatusChanged(true);
+		}
 
 		//Make it user controlled if needed
 		*start = m_chkStartTorrent->isChecked();
 		*skip_check = m_skip_data_check->isChecked();
 		
+		// set display name for non-multifile torrent as file name inside
+		if (Settings::autoRenameSingleFileTorrents() && !tc->getStats().multi_file_torrent)
+			tc->setDisplayName(QFileInfo(tc->getUserModifiedFileName()).completeBaseName());
+
 		//Now add torrent to selected group
 		if (m_cmbGroups->currentIndex() > 0)
 		{
@@ -339,6 +360,14 @@ namespace kt
 				gman->saveGroups();
 			}
 		}
+		
+		// Set this value after the group policy is applied, 
+		// so that the user selection in the dialog is not
+		// overwritten by the group policy
+		if (m_moveCompleted->checkState() == Qt::Checked)
+			tc->setMoveWhenCompletedDir(KUrl(cn));
+		else
+			tc->setMoveWhenCompletedDir(KUrl());
 
 		// update the last save directory
 		Settings::setLastSaveDir(dn);
@@ -393,7 +422,7 @@ namespace kt
 
 	void FileSelectDlg::loadGroups()
 	{
-		GroupManager::iterator it = gman->begin();
+		GroupManager::Itr it = gman->begin();
 		
 		QStringList grps;
 		
@@ -406,10 +435,13 @@ namespace kt
 		while(it != gman->end())
 		{
 			grps << it->first;		
-			if (it->second == initial_group)
-				selected = cnt + 1;
+			if (!it->second->isStandardGroup())
+			{
+				if (it->second == initial_group)
+					selected = cnt + 1;
+				cnt++;	
+			}
 			++it;
-			cnt++;
 		}
 		
 		m_cmbGroups->addItems(grps);
@@ -421,6 +453,10 @@ namespace kt
 			QString dir = initial_group->groupPolicy().default_save_location;
 			if (!dir.isNull() && bt::Exists(dir))
 				m_downloadLocation->setUrl(KUrl(dir));
+			
+			dir = initial_group->groupPolicy().default_move_on_completion_location;
+			if (!dir.isNull() && bt::Exists(dir))
+				m_completedLocation->setUrl(KUrl(dir));
 		}
 	}
 	
@@ -437,6 +473,17 @@ namespace kt
 		QString dir = g->groupPolicy().default_save_location;
 		if (!dir.isNull() && bt::Exists(dir))
 			m_downloadLocation->setUrl(KUrl(dir));
+		
+		dir = g->groupPolicy().default_move_on_completion_location;
+		if (!dir.isNull() && bt::Exists(dir))
+		{
+			m_moveCompleted->setChecked(true);
+			m_completedLocation->setUrl(KUrl(dir));
+		}
+		else
+		{
+			m_moveCompleted->setChecked(false);
+		}
 	}
 
 	void FileSelectDlg::updateSizeLabels()
@@ -444,8 +491,10 @@ namespace kt
 		if (!model)
 			return;
 		
+		updateExistingFiles();
+		
 		//calculate free disk space
-		KUrl sdir = KUrl(m_downloadLocation -> url());
+		KUrl sdir = KUrl(m_downloadLocation->url());
 		while( sdir.isValid() && sdir.isLocalFile() && (!sdir.isEmpty())  && (! QDir(sdir.toLocalFile()).exists()) ) 
 		{
 			sdir = sdir.upUrl();
@@ -463,8 +512,15 @@ namespace kt
 			Uint64 bytes_to_download = model->bytesToDownload();
 	
 			lblFree->setText(bt::BytesToString(bytes_free));
-			lblRequired->setText(bt::BytesToString(bytes_to_download));
+			if (already_downloaded > 0)
+				lblRequired->setText(
+					i18n("%1 (%2 in use by existing files)", 
+						 bt::BytesToString(bytes_to_download), 
+						 bt::BytesToString(already_downloaded)));
+			else
+				lblRequired->setText(bt::BytesToString(bytes_to_download));
 
+			bytes_to_download -= already_downloaded;
 			if (bytes_to_download > bytes_free)
 				lblStatus->setText(
 						"<font color=\"#ff0000\">" + i18nc("We are %1 bytes short of what we need", "%1 short", 
@@ -478,13 +534,24 @@ namespace kt
 	{
 		if (tc->getStats().multi_file_torrent)
 		{
+			already_downloaded = 0;
 			bt::Uint32 found = 0;
 			QString path = m_downloadLocation->url().path(KUrl::AddTrailingSlash) + tc->getDisplayName() + '/';
 			for (bt::Uint32 i = 0;i < tc->getNumFiles();i++)
 			{
 				const bt::TorrentFileInterface & file = tc->getTorrentFile(i);
-				if (bt::Exists(path + file.getPath()))
+				if (bt::Exists(path + file.getUserModifiedPath()))
+				{
 					found++;
+					if (!file.doNotDownload()) // Do not include excluded files in the already downloaded calculation
+					{
+						bt::Uint64 size = bt::DiskUsage(path + file.getUserModifiedPath());
+						if (size <= file.getSize())
+							already_downloaded += file.getSize() - size;
+						else
+							already_downloaded += file.getSize();
+					}
+				}
 			}
 			
 			if (found == 0)
@@ -498,12 +565,24 @@ namespace kt
 		{
 			QString path = m_downloadLocation->url().path(KUrl::AddTrailingSlash) + tc->getDisplayName();
 			if (!bt::Exists(path))
+			{
 				m_existing_found->setText(i18n("Existing file: <b>No</b>"));
+			}
 			else
+			{
+				already_downloaded = bt::DiskUsage(path);
 				m_existing_found->setText(i18n("Existing file: <b>Yes</b>"));
+			}
 		}
 	}
 	
+	void FileSelectDlg::downloadLocationChanged(const QString& path)
+	{
+		Q_UNUSED(path);
+		updateSizeLabels();
+	}
+
+	
 	void FileSelectDlg::onCodecChanged(const QString & text)
 	{
 		QTextCodec* codec = QTextCodec::codecForName(text.toLocal8Bit());
@@ -523,6 +602,33 @@ namespace kt
 		show_file_tree = g.readEntry("show_file_tree",true);
 		m_tree->setChecked(show_file_tree);
 		m_list->setChecked(!show_file_tree);
+		QStringList tmp = g.readEntry("download_location_history",QStringList());
+		download_location_history = QSet<QString>::fromList(tmp);
+		tmp = g.readEntry("move_on_completion_location_history",QStringList());
+		move_on_completion_location_history = QSet<QString>::fromList(tmp);
+		
+		if (download_location_history.count())
+		{
+			QMenu* m = createHistoryMenu(download_location_history,
+										 SLOT(downloadLocationHistoryTriggered(QAction*)));
+			m_download_location_history->setMenu(m); 
+		}
+		else
+			m_download_location_history->setEnabled(false);
+		
+		if (move_on_completion_location_history.count())
+		{
+			QMenu* m = createHistoryMenu(
+					move_on_completion_location_history,
+					SLOT(moveOnCompletionLocationHistoryTriggered(QAction*)));
+			m_move_when_completed_history->setMenu(m);
+		}
+		else
+			m_move_when_completed_history->setEnabled(false);
+		
+		QByteArray state = g.readEntry("file_view",QByteArray());
+		if (state.size() > 0)
+			m_file_view->header()->restoreState(state);
 	}
 	
 	
@@ -531,7 +637,52 @@ namespace kt
 		KConfigGroup g = cfg->group("FileSelectDlg");
 		g.writeEntry("size",size());
 		g.writeEntry("show_file_tree",show_file_tree);
+		g.writeEntry("download_location_history",download_location_history.toList());
+		g.writeEntry("move_on_completion_location_history",move_on_completion_location_history.toList());
+		g.writeEntry("file_view",m_file_view->header()->saveState());
 	}
+	
+	QMenu* FileSelectDlg::createHistoryMenu(const QSet<QString> & urls, const char* slot)
+	{
+		QMenu* m = new QMenu(this);
+		foreach (const QString & url,urls)
+		{
+			QAction* a = m->addAction(url);
+			a->setData(url);
+		}
+		m->addSeparator();
+		m->addAction(i18n("Clear History"));
+		connect(m,SIGNAL(triggered(QAction*)),this,slot);
+		return m;
+	}
+	
+	void FileSelectDlg::clearDownloadLocationHistory()
+	{
+		download_location_history.clear();
+		m_download_location_history->setEnabled(false);
+	}
+	
+	void FileSelectDlg::clearMoveOnCompletionLocationHistory()
+	{
+		move_on_completion_location_history.clear();
+		m_move_when_completed_history->setEnabled(false);
+	}
+
+	void FileSelectDlg::downloadLocationHistoryTriggered(QAction* act)
+	{
+		if (!act->data().isNull())
+			m_downloadLocation->setUrl(act->data().toString());
+		else
+			clearDownloadLocationHistory();
+	}
+	void FileSelectDlg::moveOnCompletionLocationHistoryTriggered(QAction* act)
+	{
+		if (!act->data().isNull())
+			m_completedLocation->setUrl(act->data().toString());
+		else
+			clearMoveOnCompletionLocationHistory();
+	}
+
 
 	void FileSelectDlg::fileTree(bool)
 	{
@@ -573,8 +724,7 @@ namespace kt
 	void FileSelectDlg::setFilter(const QString & f)
 	{
 		Q_UNUSED(f);
-		// use typedText so we don't filter on the hint
-		filter_model->setFilterFixedString(m_filter->typedText());
+		filter_model->setFilterFixedString(m_filter->text());
 	}
 
 	void FileSelectDlg::moveCompletedToggled(bool on)
