@@ -32,6 +32,7 @@
 #include <util/log.h>
 #include <settings.h>
 #include <interfaces/torrentinterface.h>
+#include <interfaces/torrentactivityinterface.h>
 #include <torrent/queuemanager.h>
 #include "core.h"
 #include "trayicon.h"
@@ -101,8 +102,11 @@ namespace kt
 		if (status_notifier_item)
 			return;
 		
-		menu = new KMenu(0);
-		KActionCollection* ac = mwnd->actionCollection();
+		status_notifier_item = new KStatusNotifierItem(mwnd);
+		connect(status_notifier_item, SIGNAL(secondaryActivateRequested(QPoint)), this, SLOT(secondaryActivate(QPoint)));
+		
+		menu = status_notifier_item->contextMenu();
+	
 		max_upload_rate = new SetMaxRate(core,SetMaxRate::UPLOAD,menu);
 		max_upload_rate->setTitle(i18n("Set max upload speed"));
 		max_download_rate = new SetMaxRate(core,SetMaxRate::DOWNLOAD,menu);
@@ -110,20 +114,25 @@ namespace kt
 		menu->addMenu(max_download_rate);
 		menu->addMenu(max_upload_rate);
 		menu->addSeparator();
+		
+		KActionCollection* ac = mwnd->getTorrentActivity()->part()->actionCollection();
 		menu->addAction(ac->action("start_all"));
 		menu->addAction(ac->action("stop_all"));
 		menu->addAction(ac->action("queue_suspend"));
 		menu->addSeparator();
+		
+		ac = mwnd->actionCollection();
 		menu->addAction(ac->action("paste_url"));
 		menu->addAction(ac->action(KStandardAction::name(KStandardAction::Open)));
 		menu->addSeparator();
 		menu->addAction(ac->action(KStandardAction::name(KStandardAction::Preferences)));
 		menu->addSeparator();
 		
-		status_notifier_item = new KStatusNotifierItem(mwnd);
+		
 		status_notifier_item->setIconByName("ktorrent");
 		status_notifier_item->setCategory(KStatusNotifierItem::ApplicationStatus);
-		status_notifier_item->setStatus(KStatusNotifierItem::Active);
+		status_notifier_item->setStatus(KStatusNotifierItem::Passive);
+		status_notifier_item->setStandardActionsEnabled(true);
 		status_notifier_item->setContextMenu(menu);
 		if (queue_suspended)
 			status_notifier_item->setOverlayIconByName("kt-pause");
@@ -135,11 +144,13 @@ namespace kt
 		if (!status_notifier_item)
 			return;
 		
+		status_notifier_item->setStatus(core->getQueueManager()->getNumRunning(QueueManager::DOWNLOADS) > 0 ?
+						KStatusNotifierItem::Active : KStatusNotifierItem::Passive);
 		QString tip = i18n("<table>"
-				"<tr><td>Download&nbsp;speed:</td><td><font color='#1c9a1c'>%1</font></td></tr>"
-				"<tr><td>Upload&nbsp;speed:</td><td><font color='#990000'>%2</font></td></tr>"
-				"<tr><td>Received:</td><td><font color='#1c9a1c'>%3</font></td></tr>"
-				"<tr><td>Transmitted:</td><td><font color='#990000'>%4</font></td></tr>"
+				"<tr><td>Download&nbsp;speed:</td><td><b>%1</b></td></tr>"
+				"<tr><td>Upload&nbsp;speed:</td><td><b>%2</b></td></tr>"
+				"<tr><td>Received:</td><td><b>%3</b></td></tr>"
+				"<tr><td>Transmitted:</td><td><b>%4</b></td></tr>"
 				"</table>",
 				BytesPerSecToString((double)stats.download_speed),
 				BytesPerSecToString((double)stats.upload_speed),
@@ -276,7 +287,7 @@ namespace kt
 		if (!Settings::showPopups())
 			return;
 		
-		QString msg = i18n("Cannot start <b>%1</b> : <br>",tc->getDisplayName());
+		QString msg = i18n("Cannot start <b>%1</b>: <br>",tc->getDisplayName());
 		switch (reason)
 		{
 		case bt::QM_LIMITS_REACHED:
@@ -342,7 +353,7 @@ namespace kt
 
 	void SetMaxRate::makeMenu()
 	{
-		int rate=(type==UPLOAD) ? Settings::maxUploadRate() : Settings::maxDownloadRate();
+		int rate = (type==UPLOAD) ? net::SocketMonitor::getUploadCap() / 1024 : net::SocketMonitor::getDownloadCap() / 1024;
 		int maxBandwidth=(rate > 0) ? rate : (type==UPLOAD) ? 0 : 20 ;
 		int delta = 0;
 		int maxBandwidthRounded;
@@ -434,6 +445,12 @@ namespace kt
 		}
 	}
 
+	void TrayIcon::secondaryActivate(const QPoint& pos)
+	{
+		Q_UNUSED(pos);
+		core->setSuspendedState(!core->getSuspendedState());
+	}
+
 }
 
 #include "trayicon.moc"
