@@ -23,20 +23,22 @@
 #include <QColor>
 #include <QPalette>
 #include <QMimeData>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kicon.h>
+#include <KLocale>
+#include <KGlobal>
+#include <KIcon>
+#include <KIconLoader>
 #include <util/log.h>
+#include <util/sha1hash.h>
 #include <util/functions.h>
 #include <interfaces/torrentinterface.h>
+#include <interfaces/trackerinterface.h>
 #include <torrent/queuemanager.h>
 #include <groups/group.h>
 #include "viewmodel.h"
 #include "core.h"
-#include <interfaces/trackerinterface.h>
-#include <util/sha1hash.h>
 #include "viewdelegate.h"
 #include "view.h"
+#include "settings.h"
 
 using namespace bt;
 
@@ -64,112 +66,113 @@ namespace kt
 		runtime_ul = tc->getRunningTimeUL() - tc->getRunningTimeDL();
 		hidden = false;
 		time_added = s.time_added;
+		highlight = false;
 	}
 			
 	
-	bool ViewModel::Item::update(int col,bool & modified)
+	bool ViewModel::Item::update(int row, int sort_column, QModelIndexList& to_update, kt::ViewModel* model)
 	{
 		bool ret = false;
 		const TorrentStats & s = tc->getStats();
 		if (status != s.status)
 		{
-			modified = true;
+			to_update.append(model->index(row,NAME));
 			status = s.status;
-			if (col == STATUS)
+			if (sort_column == NAME)
 				ret = true;
 		}
 			
 		if (bytes_downloaded != s.bytes_downloaded)
 		{
-			modified = true;
+			to_update.append(model->index(row,BYTES_DOWNLOADED));
 			bytes_downloaded = s.bytes_downloaded;
-			if (col == BYTES_DOWNLOADED)
+			if (sort_column == BYTES_DOWNLOADED)
 				ret = true;
 		}
 		
 		if (total_bytes_to_download != s.total_bytes_to_download)
 		{
-			modified = true;
+			to_update.append(model->index(row,TOTAL_BYTES_TO_DOWNLOAD));
 			total_bytes_to_download = s.total_bytes_to_download;
-			if (col == TOTAL_BYTES_TO_DOWNLOAD)
+			if (sort_column == TOTAL_BYTES_TO_DOWNLOAD)
 				ret = true;
 		}
 		
 		if (bytes_uploaded != s.bytes_uploaded)
 		{
-			modified = true;
+			to_update.append(model->index(row,BYTES_UPLOADED));
 			bytes_uploaded = s.bytes_uploaded;
-			if (col == BYTES_UPLOADED)
+			if (sort_column == BYTES_UPLOADED)
 				ret = true;
 		}
 		
 		if (download_rate != s.download_rate)
 		{
-			modified = true;
+			to_update.append(model->index(row,DOWNLOAD_RATE));
 			download_rate = s.download_rate;
-			if (col == DOWNLOAD_RATE)
+			if (sort_column == DOWNLOAD_RATE)
 				ret = true;
 		}
 		
 		if (upload_rate != s.upload_rate)
 		{
-			modified = true;
+			to_update.append(model->index(row,UPLOAD_RATE));
 			upload_rate = s.upload_rate;
-			if (col == UPLOAD_RATE)
+			if (sort_column == UPLOAD_RATE)
 				ret = true;
 		}
 		
 		int neta = tc->getETA();
 		if (eta != neta)
 		{
-			modified = true;
+			to_update.append(model->index(row,ETA));
 			eta = neta;
-			if (col == ETA)
+			if (sort_column == ETA)
 				ret = true;
 		}
 		
 		if (seeders_connected_to != s.seeders_connected_to || seeders_total != s.seeders_total)
 		{
-			modified = true;
+			to_update.append(model->index(row,SEEDERS));
 			seeders_connected_to = s.seeders_connected_to;
 			seeders_total = s.seeders_total;
-			if (col == SEEDERS)
+			if (sort_column == SEEDERS)
 				ret = true;
 		}
 		
 		if (leechers_total != s.leechers_total || leechers_connected_to != s.leechers_connected_to)
 		{
-			modified = true;
+			to_update.append(model->index(row,LEECHERS));
 			leechers_total = s.leechers_total;
 			leechers_connected_to = s.leechers_connected_to;
-			if (col == LEECHERS)
+			if (sort_column == LEECHERS)
 				ret = true;
 		}
 		
 		double perc = Percentage(s); 
 		if (fabs(percentage - perc) > 0.01)
 		{
-			modified = true;
+			to_update.append(model->index(row,PERCENTAGE));
 			percentage = perc;
-			if (col == PERCENTAGE)
+			if (sort_column == PERCENTAGE)
 				ret = true;
 		}
 		
 		float ratio = s.shareRatio();
 		if (fabsf(share_ratio - ratio) > 0.01)
 		{
-			modified = true;
+			to_update.append(model->index(row,SHARE_RATIO));
 			share_ratio = ratio;
-			if (col == SHARE_RATIO)
+			if (sort_column == SHARE_RATIO)
 				ret = true;
 		}
 		
 		Uint32 rdl = tc->getRunningTimeDL();
 		if (runtime_dl != rdl)
 		{
-			modified = true;
+			to_update.append(model->index(row,DOWNLOAD_TIME));
 			runtime_dl = rdl;
-			if (col == DOWNLOAD_TIME)
+			if (sort_column == DOWNLOAD_TIME)
 				ret = true;
 		}
 		
@@ -177,9 +180,9 @@ namespace kt
 		rul = rul >= rdl ? rul - rdl : 0; // make sure rul cannot go negative
 		if (runtime_ul != rul)
 		{
-			modified = true;
+			to_update.append(model->index(row,SEED_TIME));
 			runtime_ul = rul;
-			if (col == SEED_TIME)
+			if (sort_column == SEED_TIME)
 				ret = true;
 		}
 		return ret;
@@ -190,24 +193,23 @@ namespace kt
 		const TorrentStats & s = tc->getStats();
 		switch (col)
 		{
-			case 0: return tc->getDisplayName();
-			case 1: return s.statusToString();
-			case 2: return BytesToString(bytes_downloaded);
-			case 3: return BytesToString(total_bytes_to_download);
-			case 4: return BytesToString(bytes_uploaded);
-			case 5: 
+			case NAME: return tc->getDisplayName();
+			case BYTES_DOWNLOADED: return BytesToString(bytes_downloaded);
+			case TOTAL_BYTES_TO_DOWNLOAD: return BytesToString(total_bytes_to_download);
+			case BYTES_UPLOADED: return BytesToString(bytes_uploaded);
+			case DOWNLOAD_RATE: 
 				if (download_rate >= 103 && s.bytes_left_to_download > 0) // lowest "visible" speed, all below will be 0,0 Kb/s
 					return BytesPerSecToString(download_rate);
 				else
 					return QVariant();
 				break;
-			case 6: 
+			case UPLOAD_RATE: 
 				if (upload_rate >= 103) // lowest "visible" speed, all below will be 0,0 Kb/s
 					return BytesPerSecToString(upload_rate);
 				else
 					return QVariant();
 				break;
-			case 7: 
+			case ETA: 
 				if (eta == 0)
 					return QString("%1").arg(QChar(0x221E)); // infinity
 				else if (eta > 0)
@@ -215,15 +217,15 @@ namespace kt
 				else
 					return QVariant();
 				break;
-			case 8: return QString("%1 (%2)").arg(QString::number(seeders_connected_to)).arg(QString::number(seeders_total));
-			case 9: return QString("%1 (%2)").arg(QString::number(leechers_connected_to)).arg(QString::number(leechers_total));
+			case SEEDERS: return QString("%1 (%2)").arg(QString::number(seeders_connected_to)).arg(QString::number(seeders_total));
+			case LEECHERS: return QString("%1 (%2)").arg(QString::number(leechers_connected_to)).arg(QString::number(leechers_total));
 			// xgettext: no-c-format
-			case 10: return percentage;
-			case 11: return KGlobal::locale()->formatNumber(share_ratio,2);
-			case 12: return DurationToString(runtime_dl);
-			case 13: return DurationToString(runtime_ul);
-			case 14: return tc->getStats().output_path;
-			case 15: return KGlobal::locale()->formatDateTime(time_added);
+			case PERCENTAGE: return percentage;
+			case SHARE_RATIO: return KGlobal::locale()->formatNumber(share_ratio,2);
+			case DOWNLOAD_TIME: return DurationToString(runtime_dl);
+			case SEED_TIME: return DurationToString(runtime_ul);
+			case DOWNLOAD_LOCATION: return tc->getStats().output_path;
+			case TIME_ADDED: return KGlobal::locale()->formatDateTime(time_added);
 			default: return QVariant();
 		}
 	}
@@ -232,35 +234,34 @@ namespace kt
 	{
 		switch (col)
 		{
-			case 0: return QString::localeAwareCompare(tc->getDisplayName(),other->tc->getDisplayName()) < 0;
-			case 1: return tc->getStats().statusToString() < other->tc->getStats().statusToString();
-			case 2: return bytes_downloaded < other->bytes_downloaded;
-			case 3: return total_bytes_to_download < other->total_bytes_to_download;
-			case 4: return bytes_uploaded < other->bytes_uploaded;
-			case 5: return (download_rate < 102 ? 0 : download_rate) < (other->download_rate < 102 ? 0 : other->download_rate);
-			case 6: return (upload_rate < 102 ? 0 : upload_rate) < (other->upload_rate < 102 ? 0 : other->upload_rate);
-			case 7: 
+			case NAME: return QString::localeAwareCompare(tc->getDisplayName(),other->tc->getDisplayName()) < 0;
+			case BYTES_DOWNLOADED: return bytes_downloaded < other->bytes_downloaded;
+			case TOTAL_BYTES_TO_DOWNLOAD: return total_bytes_to_download < other->total_bytes_to_download;
+			case BYTES_UPLOADED: return bytes_uploaded < other->bytes_uploaded;
+			case DOWNLOAD_RATE: return (download_rate < 102 ? 0 : download_rate) < (other->download_rate < 102 ? 0 : other->download_rate);
+			case UPLOAD_RATE: return (upload_rate < 102 ? 0 : upload_rate) < (other->upload_rate < 102 ? 0 : other->upload_rate);
+			case ETA: 
 				if (eta == 0 && other->eta > 0)
 					return false;
 				else if (other->eta == 0 && eta > 0)
 					return true;
 				else
 					return eta < other->eta;
-			case 8: return seeders_connected_to < other->seeders_connected_to;
-			case 9: return leechers_connected_to < other->leechers_connected_to;
-			case 10: return percentage < other->percentage;
-			case 11: return share_ratio < other->share_ratio;
-			case 12: return runtime_dl < other->runtime_dl;
-			case 13: return runtime_ul < other->runtime_ul;
-			case 14: return tc->getStats().output_path < other->tc->getStats().output_path;
-			case 15: return time_added < other->time_added;
+			case SEEDERS: return seeders_connected_to < other->seeders_connected_to;
+			case LEECHERS: return leechers_connected_to < other->leechers_connected_to;
+			case PERCENTAGE: return percentage < other->percentage;
+			case SHARE_RATIO: return share_ratio < other->share_ratio;
+			case DOWNLOAD_TIME: return runtime_dl < other->runtime_dl;
+			case SEED_TIME: return runtime_ul < other->runtime_ul;
+			case DOWNLOAD_LOCATION: return tc->getStats().output_path < other->tc->getStats().output_path;
+			case TIME_ADDED: return time_added < other->time_added;
 			default: return false;
 		}
 	}
 	
 	QVariant ViewModel::Item::color(int col) const
 	{
-		if (col == 1)
+		if (col == NAME)
 		{	
 			QColor green(40,205,40);
 			QColor yellow(255,174,0);
@@ -268,6 +269,7 @@ namespace kt
 			switch (status)
 			{
 				case bt::SEEDING :
+				case bt::SUPERSEEDING:
 				case bt::DOWNLOADING:
 				case bt::ALLOCATING_DISKSPACE :
 					return green;
@@ -285,22 +287,60 @@ namespace kt
 					return QVariant();
 			}
 		}
-		else if (col == 11)
+		else if (col == SHARE_RATIO)
 		{
 			QColor green(40,205,40);
-			return share_ratio > 0.8 ? green : Qt::red;
+			return share_ratio >= Settings::greenRatio() ? green : Qt::red;
 		}
 		else
 			return QVariant();
 	}
 	
-	bool ViewModel::Item::member(Group* group) const
+	bool ViewModel::Item::visible(Group* group, const QString & filter_string) const
 	{
-		if (!group)
-			return true;
-		else
-			return group->isMember(tc);
+		if (group && !group->isMember(tc))
+			return false;
+			
+		return filter_string.isEmpty() || tc->getDisplayName().contains(filter_string, Qt::CaseInsensitive);
 	}
+	
+	QVariant ViewModel::Item::statusIcon() const
+	{
+		switch (tc->getStats().status)
+		{
+			case NOT_STARTED:
+			case STOPPED:
+				return KIcon("kt-stop");
+			case SEEDING_COMPLETE:
+			case DOWNLOAD_COMPLETE:
+				return KIcon("task-complete");
+			case SEEDING:
+			case SUPERSEEDING:
+				return KIcon("go-up");
+			case DOWNLOADING:
+				return KIcon("go-down");
+			case STALLED:
+				if (tc->getStats().completed)
+					return KIcon("go-up");
+				else
+					return KIcon("go-down");
+			case ALLOCATING_DISKSPACE:
+				return KIcon("drive-harddisk");
+			case ERROR:
+			case NO_SPACE_LEFT:
+				return KIcon("dialog-error");
+			case QUEUED:
+				return KIcon("download-later");
+			case CHECKING_DATA:
+				return KIcon("kt-check-data");
+			case PAUSED:
+				return KIcon("kt-pause");
+			default:
+				return QVariant();
+		}
+	}
+
+	////////////////////////////////////////////////////////
 
 	ViewModel::ViewModel(Core* core,View* parent) : QAbstractTableModel(parent),core(core),view(parent)
 	{
@@ -332,8 +372,28 @@ namespace kt
 	
 	void ViewModel::addTorrent(bt::TorrentInterface* ti)
 	{
-		torrents.append(new Item(ti));
+		Item* i = new Item(ti);
+		i->highlight = true;
+		
+		// Turn off highlight for previously highlighted torrents
+		foreach (Item* item,torrents)
+			if (item->highlight)
+				item->highlight = false;
+			
+		torrents.append(i);
 		update(view->viewDelegate(),true);
+		
+		// Scroll to new torrent
+		int idx = 0;
+		foreach (Item* item,torrents)
+		{
+			if (item->tc == ti)
+			{
+				view->scrollTo(index(idx, 0));
+				break;
+			}
+			idx++;
+		}
 	}
 	
 	void ViewModel::removeTorrent(bt::TorrentInterface* ti)
@@ -360,52 +420,47 @@ namespace kt
 
 	bool ViewModel::update(ViewDelegate* delegate,bool force_resort)
 	{
+		update_list.clear();
 		bool resort = force_resort;
-		Uint32 idx=0;
 		num_visible = 0;
 		
-		int lowest = -1;
-		int highest = -1;
-		
+		int row = 0;
 		foreach (Item* i,torrents)
 		{
-			bool modified = false;
-			if (i->update(sort_column,modified))
+			bool hidden = !i->visible(group, filter_string);
+			if (!hidden && i->update(row,sort_column,update_list,this))
 				resort = true;
 			
-			bool hidden = !i->member(group)/* && !delegate->extended(i->tc) */;
 			if (hidden != i->hidden)
 			{
 				i->hidden = hidden;
 				resort = true;
-				// hide the extender if there is one shown
-				if (hidden && delegate->extended(i->tc))
-					delegate->hideExtender(i->tc);
 			}
 			
+			// hide the extender if there is one shown
+			if (hidden && delegate->extended(i->tc))
+				delegate->hideExtender(i->tc);
+			
 			if (!i->hidden)
 				num_visible++;
-			
-			if (modified)
-			{
-				if (lowest == -1)
-					lowest = idx;
-				highest = idx;
-			}
-			idx++;
+			row++;
 		}
 	
 		if (resort)
 		{
+			update_list.clear();
 			sort(sort_column,sort_order);
 			return true;
 		}
-		else if (lowest != -1)
-			emit dataChanged(index(lowest,1),index(highest,14));
 		
 		return false;
 	}
 	
+	void ViewModel::setFilterString(const QString& filter)
+	{
+		filter_string = filter;
+	}
+	
 	int ViewModel::rowCount(const QModelIndex & parent) const
 	{
 		if (parent.isValid())
@@ -422,16 +477,6 @@ namespace kt
 			return _NUMBER_OF_COLUMNS;
 	}
 	
-	bool ViewModel::defaultColumnForUpload(int column)
-	{
-		return column != 2 && column != 5 && column != 10 && column != 12 && column != 14;
-	}
-	
-	bool ViewModel::defaultColumnForDownload(int column)
-	{
-		return column != 13 && column != 14;
-	}
-	
 	QVariant ViewModel::headerData(int section, Qt::Orientation orientation,int role) const
 	{
 		if (orientation != Qt::Horizontal)
@@ -441,23 +486,22 @@ namespace kt
 		{
 			switch (section)
 			{
-				case 0: return i18n("Name");
-				case 1: return i18n("Status");
-				case 2: return i18n("Downloaded");
-				case 3: return i18n("Size");
-				case 4: return i18n("Uploaded");
-				case 5: return i18n("Down Speed");
-				case 6: return i18n("Up Speed");
-				case 7: return i18n("Time Left");
-				case 8: return i18n("Seeders");
-				case 9: return i18n("Leechers");
+				case NAME: return i18n("Name");
+				case BYTES_DOWNLOADED: return i18n("Downloaded");
+				case TOTAL_BYTES_TO_DOWNLOAD: return i18n("Size");
+				case BYTES_UPLOADED: return i18n("Uploaded");
+				case DOWNLOAD_RATE: return i18n("Down Speed");
+				case UPLOAD_RATE: return i18n("Up Speed");
+				case ETA: return i18n("Time Left");
+				case SEEDERS: return i18n("Seeders");
+				case LEECHERS: return i18n("Leechers");
 				// xgettext: no-c-format
-				case 10: return i18n("% Complete");
-				case 11: return i18n("Share Ratio");
-				case 12: return i18n("Time Downloaded");
-				case 13: return i18n("Time Seeded");
-				case 14: return i18n("Location");
-				case 15: return i18n("Added");
+				case PERCENTAGE: return i18n("% Complete");
+				case SHARE_RATIO: return i18n("Share Ratio");
+				case DOWNLOAD_TIME: return i18n("Time Downloaded");
+				case SEED_TIME: return i18n("Time Seeded");
+				case DOWNLOAD_LOCATION: return i18n("Location");
+				case TIME_ADDED: return i18n("Added");
 				default: return QVariant();
 			}
 		}
@@ -465,21 +509,21 @@ namespace kt
 		{
 			switch (section)
 			{
-				case 2: return i18n("How much data we have downloaded of the torrent");
-				case 3: return i18n("Total size of the torrent, excluded files are not included");
-				case 4: return i18n("How much data we have uploaded");
-				case 5: return i18n("Current download speed");
-				case 6: return i18n("Current upload speed");
-				case 7: return i18n("How much time is left before the torrent is finished or before the maximum share ratio is reached, if that is enabled");
-				case 8: return i18n("How many seeders we are connected to (How many seeders there are according to the tracker)");
-				case 9: return i18n("How many leechers we are connected to (How many leechers there are according to the tracker)");
+				case BYTES_DOWNLOADED: return i18n("How much data we have downloaded of the torrent");
+				case TOTAL_BYTES_TO_DOWNLOAD: return i18n("Total size of the torrent, excluded files are not included");
+				case BYTES_UPLOADED: return i18n("How much data we have uploaded");
+				case DOWNLOAD_RATE: return i18n("Current download speed");
+				case UPLOAD_RATE: return i18n("Current upload speed");
+				case ETA: return i18n("How much time is left before the torrent is finished or before the maximum share ratio is reached, if that is enabled");
+				case SEEDERS: return i18n("How many seeders we are connected to (How many seeders there are according to the tracker)");
+				case LEECHERS: return i18n("How many leechers we are connected to (How many leechers there are according to the tracker)");
 				// xgettext: no-c-format
-				case 10: return i18n("The percentage of data we have of the whole torrent, not including excluded files");
-				case 11: return i18n("Share ratio is the number of bytes uploaded divided by the number of bytes downloaded");
-				case 12: return i18n("How long we have been downloading the torrent");
-				case 13: return i18n("How long we have been seeding the torrent");
-				case 14: return i18n("The location of the torrent's data on disk");
-				case 15: return i18n("When this torrent was added");
+				case PERCENTAGE: return i18n("The percentage of data we have of the whole torrent, not including excluded files");
+				case SHARE_RATIO: return i18n("Share ratio is the number of bytes uploaded divided by the number of bytes downloaded");
+				case DOWNLOAD_TIME: return i18n("How long we have been downloading the torrent");
+				case SEED_TIME: return i18n("How long we have been seeding the torrent");
+				case DOWNLOAD_LOCATION: return i18n("The location of the torrent's data on disk");
+				case TIME_ADDED: return i18n("When this torrent was added");
 				default: return QVariant();
 			}
 		}
@@ -508,34 +552,55 @@ namespace kt
 			return QVariant(); 
 		
 		if (role == Qt::ForegroundRole)
+		{
 			return item->color(index.column());
+		}
 		else if (role == Qt::DisplayRole)
+		{
 			return item->data(index.column());
-		else if (role == Qt::EditRole && index.column() == 0)
+		}
+		else if (role == Qt::EditRole && index.column() == NAME)
+		{
 			return item->tc->getDisplayName();
-		else if (role == Qt::DecorationRole && index.column() == 1)
+		}
+		else if (role == Qt::DecorationRole && index.column() == NAME)
 		{
-			bt::TorrentInterface* tc = item->tc;
-			if (tc->getTrackersList()->noTrackersReachable())
-				return KIcon("dialog-warning");
+			return item->statusIcon();
 		} 
-		else if (role == Qt::ToolTipRole)
+		else if (role == Qt::ToolTipRole && index.column() == NAME)
 		{
-			if (index.column() == 1)
+			QString tooltip; 
+			bt::TorrentInterface* tc = item->tc;
+			if (tc->loadUrl().isValid())
+				tooltip = i18n("%1<br>Url: <b>%2</b>",tc->getDisplayName(),tc->loadUrl().prettyUrl());
+			else
+				tooltip = tc->getDisplayName();
+			
+			tooltip += "<br/><br/>" + tc->getStats().statusToString();
+			if (tc->getTrackersList()->noTrackersReachable())
+				tooltip += i18n("<br/><br/>Unable to contact a tracker.");
+			
+			return tooltip;
+		}
+		else if (role == Qt::TextAlignmentRole)
+		{
+			switch (index.column())
 			{
-				bt::TorrentInterface* tc = item->tc;
-				if (tc->getTrackersList()->noTrackersReachable())
-					return i18n("Unable to contact a tracker.");
-			}
-			else if (index.column() == 0)
-			{
-				bt::TorrentInterface* tc = item->tc;
-				if (tc->loadUrl().isValid())
-					return i18n("%1<br>Url: <b>%2</b>",tc->getDisplayName(),tc->loadUrl().prettyUrl());
-				else
-					return tc->getDisplayName();
+				case NAME:
+				case PERCENTAGE:
+				case DOWNLOAD_LOCATION:
+				case TIME_ADDED:
+					return Qt::AlignLeft;
+				default:
+					return Qt::AlignRight;
 			}
 		}
+		else if (role == Qt::FontRole && item->highlight)
+		{
+			QFont f = view->font();
+			f.setBold(true);
+			return f;
+		}
 		
 		return QVariant();
 	}
@@ -543,7 +608,7 @@ namespace kt
 	bool ViewModel::setData(const QModelIndex & index,const QVariant & value,int role)
 	{
 		if (!index.isValid() || index.row() >= torrents.count() || index.row() < 0 || 
-			role != Qt::EditRole || index.column() != 0)
+			role != Qt::EditRole || index.column() != NAME)
 			return false; 
 		
 		QString name = value.toString();
@@ -565,7 +630,7 @@ namespace kt
 			return QAbstractTableModel::flags(index) | Qt::ItemIsDropEnabled;
 		
 		Qt::ItemFlags flags = QAbstractTableModel::flags(index) | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
-		if (index.column() == 0 )
+		if (index.column() == NAME)
 			flags |= Qt::ItemIsEditable;
 		
 		return flags;
@@ -672,7 +737,7 @@ namespace kt
 	{
 		foreach (Item* item,torrents)
 		{
-			if (item->member(group))
+			if (item->visible(group, filter_string))
 				tlist.append(item->tc);
 		}
 	}
@@ -727,10 +792,6 @@ namespace kt
 		sort_order = order;
 		emit layoutAboutToBeChanged();
 		qStableSort(torrents.begin(),torrents.end(),ViewModelItemCmp(col,order));
-	/*	Out(SYS_GEN|LOG_DEBUG) << "Sort results:" << endl;
-		foreach (Item* i,torrents)
-			Out(SYS_GEN|LOG_DEBUG) << "Item: " << i->hidden << " " << i->tc->getDisplayName() << endl;
-		*/
 		emit layoutChanged();
 		emit sorted();
 	}
