@@ -30,11 +30,12 @@
 #include <torrent/choker.h>
 #include <peer/authenticationmonitor.h>
 #include <peer/peermanager.h>
+#include <peer/peerconnector.h>
 #include <peer/utpex.h>
 #include <net/socketmonitor.h>
 #include <net/socks.h>
 #include <dht/dhtbase.h>
-#include <mse/streamsocket.h>
+#include <mse/encryptedpacketsocket.h>
 #include <tracker/httptracker.h>
 #include <tracker/udptrackersocket.h>
 #include <diskio/chunkmanager.h>
@@ -47,6 +48,7 @@
 #include "settings.h"
 #include "functions.h"
 
+
 using namespace bt;
 
 namespace kt
@@ -62,6 +64,19 @@ namespace kt
 			return str;
 	}
 	
+	Uint16 RandomGoodPort()
+	{
+		Uint16 start = 50000;
+		while (true)
+		{
+			Uint16 port = start + qrand() % 10000;
+			if (port != Settings::port() && 
+				port != Settings::dhtPort() &&
+				port != Settings::udpTrackerPort())
+				return port;
+		}
+	}
+	
 	void ApplySettings()
 	{
 		PeerManager::setMaxConnections(Settings::maxConnections());
@@ -69,13 +84,15 @@ namespace kt
 		net::SocketMonitor::setDownloadCap(Settings::maxDownloadRate()*1024);
 		net::SocketMonitor::setUploadCap(Settings::maxUploadRate()*1024);
 		net::SocketMonitor::setSleepTime(Settings::cpuUsage());
-		mse::StreamSocket::setTOS(Settings::dscp() << 2);
-		mse::StreamSocket::setMaxConnecting(Settings::maxConnectingSockets());
-		ChunkManager::setUploadDataCheckingEnabled(Settings::doUploadDataCheck());
-		if (!Settings::useMaxSizeForUploadDataCheck())
-			ChunkManager::setMaxChunkSizeForDataCheck(0);
-		else
-			ChunkManager::setMaxChunkSizeForDataCheck(Settings::maxSizeForUploadDataCheck() * 1024);
+		mse::EncryptedPacketSocket::setTOS(Settings::dscp() << 2);
+		bt::PeerConnector::setMaxActive(Settings::maxConnectingSockets());
+		
+		// Check for port conflicts
+		if (Settings::port() == Settings::udpTrackerPort())
+			Settings::setUdpTrackerPort(RandomGoodPort());
+		
+		if (Settings::port() == Settings::dhtPort())
+			Settings::setDhtPort(RandomGoodPort());
 	
 		UDPTrackerSocket::setPort(Settings::udpTrackerPort());
 		Choker::setNumUploadSlots(Settings::numUploadSlots());
@@ -125,8 +142,6 @@ namespace kt
 		
 		bt::TorrentControl::setDataCheckWhenCompleted(Settings::checkWhenFinished());
 		bt::TorrentControl::setMinimumDiskSpace(Settings::minDiskSpace());
-		bt::TorrentControl::setAutoRecheck(Settings::autoRecheck());
-		bt::TorrentControl::setNumCorruptedForRecheck(Settings::maxCorruptedBeforeRecheck());
 		
 		
 		if (Settings::networkInterface() == 0)
@@ -158,6 +173,14 @@ namespace kt
 		bt::Downloader::setUseWebSeeds(Settings::webseedsEnabled());
 		bt::Peer::setResolveHostnames(Settings::lookUpHostnameOfPeers());
 	}
+	
+	QString TorrentFileFilter(bool all_files_included)
+	{
+		QString ret = QString("*.torrent|%1").arg(i18n("Torrents"));
+		if (all_files_included)
+			ret += "\n*|" + i18n("All files");
+		return ret;
+	}
 
 
 }
