@@ -18,25 +18,27 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include <math.h>
-#include <float.h>
-#include <qdatetime.h>
-#include <qcheckbox.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <QDateTime>
+#include <QCheckBox>
+#include <KGlobal>
+#include <KLocale>
+#include <KRun>
 #include <util/functions.h>
 #include <util/log.h>
-#include <interfaces/torrentinterface.h>
-
+#include <util/sha1hash.h>
 #include "downloadedchunkbar.h"
 #include "availabilitychunkbar.h"
 #include "statustab.h"
+#include "settings.h"
+
+
 		
 using namespace bt;
 
 namespace kt
 {
 
-	StatusTab::StatusTab(QWidget* parent) : QWidget(parent),curr_tc(0)
+	StatusTab::StatusTab(QWidget* parent) : QWidget(parent)
 	{
 		setupUi(this);
 		// do not use hardcoded colors
@@ -51,6 +53,7 @@ namespace kt
 		avg_up_speed->setFont(f);
 		type->setFont(f);
 		comments->setFont(f);
+		info_hash->setFont(f);
 		
 		ratio_limit->setMinimum(0.0f);
 		ratio_limit->setMaximum(100.0f);
@@ -70,6 +73,9 @@ namespace kt
 		int h = (int)ceil(fontMetrics().height()*1.25);
 		downloaded_bar->setFixedHeight(h);
 		availability_bar->setFixedHeight(h);
+		
+		comments->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::LinksAccessibleByKeyboard|Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);
+		connect(comments,SIGNAL(linkActivated(QString)),SLOT(linkActivated(QString)));
 
 		// initialize everything with curr_tc == 0
 		setEnabled(false);
@@ -79,6 +85,7 @@ namespace kt
 		comments->clear();
 		avg_up_speed->clear();
 		avg_down_speed->clear();
+		info_hash->clear();
 	}
 	
 	StatusTab::~StatusTab()
@@ -86,10 +93,10 @@ namespace kt
 
 	void StatusTab::changeTC(bt::TorrentInterface* tc)
 	{
-		if (tc == curr_tc)
+		if (tc == curr_tc.data())
 			return;
 	
-		curr_tc = tc;
+		curr_tc = bt::TorrentInterface::WPtr(tc);
 	
 		downloaded_bar->setTC(tc);
 		availability_bar->setTC(tc);
@@ -97,16 +104,27 @@ namespace kt
 		
 		if (curr_tc)
 		{
+			info_hash->setText(tc->getInfoHash().toString());
 			type->setText(tc->getStats().priv_torrent ? i18n("Private") : i18n("Public"));
 
 			// Don't allow multiple lines in the comments field
 			QString text = tc->getComments();
 			if (text.contains("\n"))
-				comments->setText(text.replace("\n"," "));
-			else
-				comments->setText(text);
+				text = text.replace("\n"," ");
+			
+			// Make links clickable
+			QStringList words = text.split(" ",QString::KeepEmptyParts);
+			for (QStringList::iterator i = words.begin();i != words.end();i++)
+			{
+				QString & w = *i;
+				if (w.startsWith("http://") || w.startsWith("https://") || w.startsWith("ftp://"))
+					w = "<a href=\"" + w + "\">" + w + "</a>";
+			}
+			
+			comments->setText(words.join(" "));
+			
 
-			float ratio = curr_tc->getMaxShareRatio();
+			float ratio = tc->getMaxShareRatio();
 			if(ratio > 0)
 			{
 				use_ratio_limit->setChecked(true);
@@ -120,7 +138,7 @@ namespace kt
 				ratio_limit->setEnabled(false);
 			}
 			
-			float hours = curr_tc->getMaxSeedTime();
+			float hours = tc->getMaxSeedTime();
 			if (hours > 0)
 			{
 				time_limit->setEnabled(true);
@@ -136,6 +154,7 @@ namespace kt
 		}
 		else
 		{
+			info_hash->clear();
 			ratio_limit->setValue(0.00f);
 			time_limit->setValue(0.0);
 			share_ratio->clear();
@@ -153,7 +172,8 @@ namespace kt
 		if (!curr_tc)
 			return;
 	
-		const bt::TorrentStats & s = curr_tc->getStats();
+		bt::TorrentInterface* tc = curr_tc.data();
+		const bt::TorrentStats & s = tc->getStats();
 		
 		downloaded_bar->updateBar();
 		availability_bar->updateBar();
@@ -165,9 +185,9 @@ namespace kt
 		if (!time_limit->hasFocus())
 			maxSeedTimeUpdate();
 		
-		share_ratio->setText(QString("<font color=\"%1\">%2</font>").arg(ratio <= 0.8 ? "#ff0000" : "#1c9a1c").arg(KGlobal::locale()->formatNumber(ratio,2)));
+		share_ratio->setText(QString("<font color=\"%1\">%2</font>").arg(ratio <= Settings::greenRatio() ? "#ff0000" : "#1c9a1c").arg(KGlobal::locale()->formatNumber(ratio,2)));
 	
-		Uint32 secs = curr_tc->getRunningTimeUL(); 
+		Uint32 secs = tc->getRunningTimeUL(); 
 		if (secs == 0)
 		{
 			avg_up_speed->setText(BytesPerSecToString(0));
@@ -178,7 +198,7 @@ namespace kt
 			avg_up_speed->setText(BytesPerSecToString(r / secs));
 		}
 		
-		secs = curr_tc->getRunningTimeDL();
+		secs = tc->getRunningTimeDL();
 		if (secs == 0)
 		{
 			avg_down_speed->setText(BytesPerSecToString(0));
@@ -200,7 +220,7 @@ namespace kt
 		if(!curr_tc)
 			return;
 		
-		curr_tc->setMaxShareRatio(v);
+		curr_tc.data()->setMaxShareRatio(v);
 	}
 	
 	void StatusTab::useRatioLimitToggled(bool state)
@@ -208,26 +228,28 @@ namespace kt
 		if(!curr_tc)
 			return;
 		
+		bt::TorrentInterface* tc = curr_tc.data();
+		
 		ratio_limit->setEnabled(state);
 		if (!state)
 		{
-			curr_tc->setMaxShareRatio(0.00f);
+			tc->setMaxShareRatio(0.00f);
 			ratio_limit->setValue(0.00f);
 		}
 		else
 		{
-			float msr = curr_tc->getMaxShareRatio();
+			float msr = tc->getMaxShareRatio();
 			if(msr == 0.00f)
 			{	
-				curr_tc->setMaxShareRatio(1.00f);
+				tc->setMaxShareRatio(1.00f);
 				ratio_limit->setValue(1.00f);
 			}
 			
-			float sr = curr_tc->getStats().shareRatio();
+			float sr = tc->getStats().shareRatio();
 			if(sr >= 1.00f)
 			{
 				//always add 1 to max share ratio to prevent stopping if torrent is running.
-				curr_tc->setMaxShareRatio(sr + 1.00f);
+				tc->setMaxShareRatio(sr + 1.00f);
 				ratio_limit->setValue(sr + 1.00f);
 			}
 		}
@@ -238,7 +260,7 @@ namespace kt
 		if(!curr_tc)
 			return;
 		
-		float ratio = curr_tc->getMaxShareRatio();
+		float ratio = curr_tc.data()->getMaxShareRatio();
 		if (ratio > 0.00f)
 		{
 			// only update when needed
@@ -266,7 +288,7 @@ namespace kt
 		if(!curr_tc)
 			return;
 		
-		float time = curr_tc->getMaxSeedTime();
+		float time = curr_tc.data()->getMaxSeedTime();
 		if (time > 0.00f)
 		{
 			// only update when needed
@@ -294,26 +316,33 @@ namespace kt
 		if(!curr_tc)
 			return;
 		
+		bt::TorrentInterface* tc = curr_tc.data();
 		time_limit->setEnabled(on);
 		if (on)
 		{
-			Uint32 dl = curr_tc->getRunningTimeDL();
-			Uint32 ul = curr_tc->getRunningTimeUL();
+			Uint32 dl = tc->getRunningTimeDL();
+			Uint32 ul = tc->getRunningTimeUL();
 			float hours = (ul - dl) / 3600.0f + 1.0; // add one hour to current seed time to not stop immediatly
 			time_limit->setValue(hours); 
-			curr_tc->setMaxSeedTime(hours);
+			tc->setMaxSeedTime(hours);
 		}
 		else
 		{
-			curr_tc->setMaxSeedTime(0.0f);
+			tc->setMaxSeedTime(0.0f);
 		}
 	}
 	
 	void StatusTab::maxTimeChanged(double v)
 	{
 		if (curr_tc)
-			curr_tc->setMaxSeedTime(v);
+			curr_tc.data()->setMaxSeedTime(v);
 	}
+	
+	void StatusTab::linkActivated(const QString& link)
+	{
+		KRun::runUrl(KUrl(link),"text/html",0);
+	}
+
 
 }
 
