@@ -42,7 +42,7 @@ namespace kt
 	
 	
 	TrackerView::TrackerView(QWidget *parent)
-		: QWidget(parent), tc(0)
+		: QWidget(parent)
 	{
 		setupUi(this);
 		model = new TrackerModel(this);
@@ -102,7 +102,7 @@ namespace kt
 				continue;
 			
 			KUrl url(line.trimmed());
-			if (!url.isValid())
+			if (!url.isValid() || (url.protocol() != "udp" && url.protocol() != "http" && url.protocol() != "https"))
 				invalid.append(line);
 			else
 				urls.append(url);
@@ -113,22 +113,24 @@ namespace kt
 			KMessageBox::errorList(this, i18n("Several URL's could not be added because they are malformed:"),invalid);
 		}
 			
+		KUrl::List dupes;
 		QList<bt::TrackerInterface*> tl;
 		foreach (const KUrl & url,urls)
 		{
-			// check for dupes
-			bt::TrackerInterface* trk = tc->getTrackersList()->addTracker(url,true);
+			bt::TrackerInterface* trk = tc.data()->getTrackersList()->addTracker(url,true);
 			if (!trk)
-			{
-				KMessageBox::sorry(0,i18n("There already is a tracker named <b>%1</b>.",url.prettyUrl()));
-			}
+				dupes.append(url);
 			else
-			{
 				tl.append(trk);
-			}
 		}
 		
-		model->addTrackers(tl);
+		if (dupes.size() == 1)
+			KMessageBox::sorry(0,i18n("There already is a tracker named <b>%1</b>.",dupes.front().prettyUrl()));
+		else if (dupes.size() > 1)
+			KMessageBox::informationList(0,i18n("The following duplicate trackers were not added:"),dupes.toStringList());
+		
+		if (!tl.isEmpty())
+			model->addTrackers(tl);
 	}
 
 	void TrackerView::removeClicked()
@@ -143,10 +145,10 @@ namespace kt
 	void TrackerView::changeClicked()
 	{
 		QModelIndex current = m_tracker_list->selectionModel()->currentIndex();
-		if (!current.isValid())
+		if (!current.isValid() || tc.isNull())
 			return;
 		
-		bt::TrackersList* tlist = tc->getTrackersList();
+		bt::TrackersList* tlist = tc.data()->getTrackersList();
 		bt::TrackerInterface* trk = model->tracker(proxy_model->mapToSource(current));
 		if (trk && trk->isEnabled())
 			tlist->setCurrentTracker(trk);
@@ -154,9 +156,12 @@ namespace kt
 
 	void TrackerView::restoreClicked()
 	{
-		tc->getTrackersList()->restoreDefault();
-		tc->updateTracker();
-		model->changeTC(tc); // trigger reset
+		if (tc)
+		{
+			tc.data()->getTrackersList()->restoreDefault();
+			tc.data()->updateTracker();
+			model->changeTC(tc.data()); // trigger reset
+		}
 	}
 
 	void TrackerView::updateClicked()
@@ -164,7 +169,7 @@ namespace kt
 		if(!tc)
 			return;
 		
-		tc->updateTracker();
+		tc.data()->updateTracker();
 	}
 	
 	void TrackerView::scrapeClicked()
@@ -172,12 +177,12 @@ namespace kt
 		if(!tc)
 			return;
 		
-		tc->scrapeTracker();
+		tc.data()->scrapeTracker();
 	}
 	
 	void TrackerView::changeTC(TorrentInterface* ti)
 	{
-		if (tc == ti)
+		if (tc.data() == ti)
 			return;
 		
 		setEnabled(ti != 0);
@@ -209,7 +214,7 @@ namespace kt
 			m_remove_tracker->setEnabled(true);
 			m_restore_defaults->setEnabled(true);
 			m_scrape->setEnabled(true);
-			model->changeTC(tc);
+			model->changeTC(ti);
 			currentChanged(m_tracker_list->selectionModel()->currentIndex(),QModelIndex());
 		}
 	}
@@ -224,12 +229,12 @@ namespace kt
 			return;
 		}
 		
-		const TorrentStats & s = tc->getStats();
+		const TorrentStats & s = tc.data()->getStats();
 	
 		bt::TrackerInterface* trk = model->tracker(proxy_model->mapToSource(current));
 		bool enabled = trk ? trk->isEnabled() : false;
-		m_change_tracker->setEnabled(s.running && model->rowCount(QModelIndex()) > 1 && enabled);
-		m_remove_tracker->setEnabled(trk && tc->getTrackersList()->canRemoveTracker(trk));
+		m_change_tracker->setEnabled(s.running && model->rowCount(QModelIndex()) > 1 && enabled && s.priv_torrent);
+		m_remove_tracker->setEnabled(trk && tc.data()->getTrackersList()->canRemoveTracker(trk));
 	}
 	
 	void TrackerView::saveState(KSharedConfigPtr cfg)
