@@ -25,6 +25,8 @@
 #include <QStringList>
 #include <taglib/fileref.h>
 #include <util/ptrmap.h>
+#include "mediafile.h"
+#include "mediamodel.h"
 
 namespace kt
 {
@@ -36,18 +38,16 @@ namespace kt
 	{
 		Q_OBJECT
 	public:
-		PlayList(QObject* parent);
+		PlayList(MediaFileCollection* collection, MediaPlayer* player, QObject* parent);
 		virtual ~PlayList();
 		
-		void addFile(const QString & file);
-		void removeFile(const QString & file);
-		QString fileForIndex(const QModelIndex& index) const;
+		void addFile(const MediaFileRef & file);
+		void removeFile(const MediaFileRef & file);
+		MediaFileRef fileForIndex(const QModelIndex& index) const;
 		void save(const QString & file);
 		void load(const QString & file);
 		void clear();
 		
-		
-		
 		virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
 		virtual QVariant headerData(int section, Qt::Orientation orientation,int role) const;
 		virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
@@ -62,11 +62,19 @@ namespace kt
 		virtual bool removeRows(int row,int count,const QModelIndex & parent);
 		virtual bool insertRows(int row,int count,const QModelIndex & parent);
 		
+		
+	private slots:
+		void onPlaying(const MediaFileRef & file);
+		
+	signals:
+		void itemsDropped();
 			
 	private:
-		QStringList files;
-		mutable bt::PtrMap<QString,TagLib::FileRef> tags;
+		typedef QPair<MediaFileRef,TagLib::FileRef*> PlayListItem;
+		mutable QList<PlayListItem> files;
 		mutable QList<int> dragged_rows;
+		MediaFileCollection* collection;
+		MediaPlayer* player;
 	};
 }
 
